%define major		11
%define libname		%mklibname %{name} %{major}
%define olddevel	%libname-devel
%define libnamedevel	%mklibname %{name} -d
%define tarballver	%(echo %version|sed -e 's/\\./-/g')

Name:		vigra
Version:	1.12.1
Release:	%mkrel 4
Summary:	Generic Programming for Computer Vision
License:	MIT
Group:		Development/C
URL:		https://ukoethe.github.io/vigra/
Source0:	https://github.com/ukoethe/vigra/archive/Version-%{tarballver}/%{name}-%{version}.tar.gz
#Source0:	https://github.com/ukoethe/vigra/releases/download/Version-%%{tarballver}/%%{name}-%%{version}-src.tar.gz
# https://github.com/ukoethe/vigra/issues/588
Patch0:		vigra-cmake-module-dir.patch
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	boost-devel
BuildRequires:	hdf5-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(fftw3) >= 3
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	python3-numpy-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(pytest)
BuildRequires:	python3dist(sphinx)

%description
VIGRA stands for "Vision with Generic Algorithms". It's a novel computer vision
library that puts its main emphasis on customizable algorithms and data
structures. By using template techniques similar to those in the C++ Standard
Template Library, you can easily adapt any VIGRA component to the needs of your
application without thereby giving up execution speed.

%package -n	%{libname}
Summary:	Library of vigra library
Group:		Development/C

%description -n	%{libname}
VIGRA stands for "Vision with Generic Algorithms". It's a novel computer vision
library that puts its main emphasis on customizable algorithms and data
structures. By using template techniques similar to those in the C++ Standard
Template Library, you can easily adapt any VIGRA component to the needs of your
application without thereby giving up execution speed.

%package -n	%{libnamedevel}
Summary:	Development tools for programs which will use the vigra library
Group:		Development/C
Requires:	%{libname} = %{version}
Requires:	python3dist(sphinx)
Requires:	python3-numpy-devel
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{libnamedevel}
The %{libnamedevel} package includes the header files necessary for developing
programs that use the %{name} library.

%package -n	python3-%{name}
Summary:	Python 3 interface for the vigra computer vision library
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}
Requires:	python3dist(numpy)
Provides:	%{name}-python = %{version}-%{release}
Provides:	python-%{name} = %{version}-%{release}

%description -n	python3-%{name}
The python3-%{name} package provides python 3 bindings for %{name}.

%prep
%autosetup -p1 -n %{name}-Version-%{tarballver}

# cleanup
rm -f doc/vigranumpy/.buildinfo

# python shebang
sed -i '1s=^#!/usr/bin/\(python\|env python\)[0-9.]*=#!%{python3}=' config/vigra-config.in

%build
%cmake \
	-DDOCINSTALL=share/doc/%{name} \
	-DPYTHON_VERSION=%{python3_version} \
	-DVIGRANUMPY_INSTALL_DIR=%{python3_sitearch} \
	-DWITH_OPENEXR=ON
%cmake_build -j4

%install
%cmake_install

%files -n %{libname}
%{_libdir}/lib%{name}impex.so.%{major}{,.*}

%files -n %{libnamedevel}
%doc %{_datadir}/doc/%{name}
%{_bindir}/%{name}-config
%{_includedir}/%{name}/
%{_libdir}/lib%{name}impex.so
%{_libdir}/cmake/%{name}/
%{_libdir}/cmake/vigranumpy/

%files -n python3-%{name}
%{python3_sitearch}/%{name}/


%changelog
* Tue Jan 28 2025 daviddavid <daviddavid> 1.12.1-4.mga10
+ Revision: 2142850
- remove unneeded python3-nose build dependency

* Fri Sep 13 2024 wally <wally> 1.12.1-3.mga10
+ Revision: 2095535
- rebuild for boost 1.86.0

* Tue Sep 10 2024 daviddavid <daviddavid> 1.12.1-2.mga10
+ Revision: 2094796
- cmake modules must be in cmake subdir (aka: /usr/lib(64)/cmake/_module_/)

* Mon Sep 09 2024 daviddavid <daviddavid> 1.12.1-1.mga10
+ Revision: 2094756
- new version: 1.12.1
- avoid numpy.distutils
- rebuild for new hdf5 1.14.4.3

* Wed Jun 19 2024 wally <wally> 1.11.1-36.mga10
+ Revision: 2075404
- rebuild for boost 1.85.0

* Fri Jan 12 2024 wally <wally> 1.11.1-35.mga10
+ Revision: 2030608
- rebuild for boost 1.84.0

* Thu Dec 28 2023 daviddavid <daviddavid> 1.11.1-34.mga10
+ Revision: 2023250
- rebuild for py3.12

* Wed Sep 27 2023 wally <wally> 1.11.1-33.mga10
+ Revision: 1991512
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 1.11.1-32.mga9
+ Revision: 1926540
- rebuild for boost 1.81.0

* Mon Dec 12 2022 ns80 <ns80> 1.11.1-31.mga9
+ Revision: 1921142
- rebuild for new libtiff

* Mon Dec 05 2022 papoteur <papoteur> 1.11.1-30.mga9
+ Revision: 1918314
- rebuild for hdf5 1.12.2

* Mon Dec 05 2022 daviddavid <daviddavid> 1.11.1-29.mga9
+ Revision: 1918241
- rebuild for new hdf5 1.12.2

* Sun Jul 03 2022 wally <wally> 1.11.1-28.mga9
+ Revision: 1867321
- rebuild for boost 1.79.0

* Fri Apr 01 2022 umeabot <umeabot> 1.11.1-27.mga9
+ Revision: 1838175
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tmb <tmb> 1.11.1-26.mga9
+ Revision: 1774875
- rebuild for python 3.10

* Sat Dec 25 2021 wally <wally> 1.11.1-25.mga9
+ Revision: 1763712
- add Fedora patch to find openexr3 when building

* Sat Dec 25 2021 wally <wally> 1.11.1-24.mga9
+ Revision: 1763679
- rebuild for openexr 3.1.3

* Wed Dec 22 2021 wally <wally> 1.11.1-23.mga9
+ Revision: 1763312
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 1.11.1-22.mga9
+ Revision: 1762600
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.11.1-21.mga9
+ Revision: 1744657
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.11.1-20.mga9
+ Revision: 1723030
- rebuild for boost 1.76.0

* Sat Mar 20 2021 daviddavid <daviddavid> 1.11.1-19.mga9
+ Revision: 1705400
- rebuild for python 3.9

* Thu Dec 31 2020 wally <wally> 1.11.1-18.mga8
+ Revision: 1666828
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.11.1-17.mga8
+ Revision: 1662070
- rebuild for boost 1.74.0

* Sat Sep 12 2020 daviddavid <daviddavid> 1.11.1-16.mga8
+ Revision: 1625005
- rebuild for new openexr 2.5.3

* Sun May 03 2020 wally <wally> 1.11.1-15.mga8
+ Revision: 1578124
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 1.11.1-14.mga8
+ Revision: 1545016
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 wally <wally> 1.11.1-13.mga8
+ Revision: 1483723
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Sep 25 2019 daviddavid <daviddavid> 1.11.1-12.mga8
+ Revision: 1445789
- rebuild for python3.8

* Wed Jul 17 2019 daviddavid <daviddavid> 1.11.1-11.mga8
+ Revision: 1422057
- switch to Python3

* Sat May 25 2019 daviddavid <daviddavid> 1.11.1-10.mga7
+ Revision: 1399053
- rebuild for new hdf5 1.10.5

* Thu Nov 08 2018 daviddavid <daviddavid> 1.11.1-9.mga7
+ Revision: 1328912
- rebuild for new hdf5 1.10.4

* Tue Oct 16 2018 wally <wally> 1.11.1-8.mga7
+ Revision: 1321113
- rebuild for new boost 1.68.0

* Mon Oct 15 2018 daviddavid <daviddavid> 1.11.1-7.mga7
+ Revision: 1320483
- rebuild for new openexr 2.3.0

* Tue Oct 02 2018 daviddavid <daviddavid> 1.11.1-6.mga7
+ Revision: 1315643
- add upstream patch to fix build with gcc8
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun May 27 2018 wally <wally> 1.11.1-5.mga7
+ Revision: 1232432
- rebuild for openexr 2.2.1

* Sat Jan 13 2018 wally <wally> 1.11.1-4.mga7
+ Revision: 1192571
- rebuild for new ilmbase

* Mon Dec 25 2017 wally <wally> 1.11.1-3.mga7
+ Revision: 1184776
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1.11.1-2.mga7
+ Revision: 1178355
- rebuild for boost 1.65

* Sun Sep 17 2017 daviddavid <daviddavid> 1.11.1-1.mga7
+ Revision: 1155019
- new version: 1.11.1
- now libmajor is 11
- rename python-vigra to python2-vigra
+ tv <tv>
- rebuild with latest boost

* Sat Dec 26 2015 daviddavid <daviddavid> 1.10.0-7.mga6
+ Revision: 915161
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 1.10.0-6.mga6
+ Revision: 883847
- rename subpackage vigra-python to python-vigra
- rename subpackage vigra-devel to lib(64)vigra-devel
- switch BuildRequires to pkgconfig()
- use new python2 macros
- rebuild for new boost 1.59.0

* Wed Aug 26 2015 fwang <fwang> 1.10.0-5.mga6
+ Revision: 869503
- rebuild for gcc5

* Wed Aug 12 2015 fwang <fwang> 1.10.0-4.mga6
+ Revision: 863444
- fix wrong lib packaging

* Wed Aug 12 2015 fwang <fwang> 1.10.0-3.mga6
+ Revision: 863424
- force build with openexr support

* Wed Aug 12 2015 fwang <fwang> 1.10.0-2.mga6
+ Revision: 863423
- enable openexr support

* Wed Aug 12 2015 fwang <fwang> 1.10.0-1.mga6
+ Revision: 863409
- add cmake file
- update file list
- do not build parallel
- 1.10.0
- add more python br
+ daviddavid <daviddavid>
- rebuild for new boost-1.58.0

* Tue Jul 21 2015 daviddavid <daviddavid> 1.9.0-8.mga6
+ Revision: 855922
- rebuild with new hdf5

* Wed Oct 15 2014 umeabot <umeabot> 1.9.0-7.mga5
+ Revision: 743918
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.9.0-6.mga5
+ Revision: 730709
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Sat Feb 08 2014 barjac <barjac> 1.9.0-3.mga5
+ Revision: 586846
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.9.0-2.mga4
+ Revision: 530083
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 fwang <fwang> 1.9.0-1.mga4
+ Revision: 455011
- new version 1.9.0

* Tue Jul 16 2013 fwang <fwang> 1.8.0-10.mga4
+ Revision: 455009
- rebuild for new hdf5

* Mon Jul 15 2013 fwang <fwang> 1.8.0-9.mga4
+ Revision: 454593
- rebuild for new boost

* Sun Jun 02 2013 fwang <fwang> 1.8.0-8.mga4
+ Revision: 434964
- rebuild for new libpng

* Thu Apr 11 2013 ennael <ennael> 1.8.0-7.mga3
+ Revision: 409506
- rebuild for boost-1.53

* Mon Jan 14 2013 umeabot <umeabot> 1.8.0-6.mga3
+ Revision: 385413
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.8.0-5.mga3
+ Revision: 333125
- rebuild for new boost

* Fri Aug 03 2012 fwang <fwang> 1.8.0-4.mga3
+ Revision: 278116
- fix build with gcc 4.7
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 1.8.0-3.mga3
+ Revision: 250140
- rebuild for new boost

* Sun Dec 25 2011 fwang <fwang> 1.8.0-2.mga2
+ Revision: 187454
- rebuild for new lbitiff

* Sun Dec 11 2011 eatdirt <eatdirt> 1.8.0-1.mga2
+ Revision: 180500
- Upgrade to 1.8.0

* Mon Nov 28 2011 fwang <fwang> 1.7.1-3.mga2
+ Revision: 173669
- rebuild for new boost

* Sun Sep 11 2011 grenoya <grenoya> 1.7.1-2.mga2
+ Revision: 142487
- replace require of numpy and numpy-f2py by python-numpy-devel (it contains f2py and will pull python-numpy)

* Sun Sep 11 2011 fwang <fwang> 1.7.1-1.mga2
+ Revision: 142330
- fix group
- update file list
- update file list
- clean spec
- update file list
- new version 1.7.1
- add gentoo patch to build with libpng1.5
- add more br
- fix br
- rebuild for new libpng
+ dmorgan <dmorgan>
- New version 1.7.0
  Sync with fedora

* Sun Jan 23 2011 dmorgan <dmorgan> 1.5.0-7.mga1
+ Revision: 34527
- Remove mdv macros
- add %%{name}-devel on the devel package
- imported package vigra


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 1.5.0-7mdv2011.0
+ Revision: 608124
- rebuild

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 1.5.0-6mdv2010.1
+ Revision: 488807
- rebuilt against libjpeg v8

* Wed Sep 09 2009 Thierry Vignaud <tv@mandriva.org> 1.5.0-5mdv2010.0
+ Revision: 434673
- rebuild
- rebuild

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 1.5.0-3mdv2009.0
+ Revision: 255552
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.5.0-1mdv2008.1
+ Revision: 136570
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Jul 23 2007 Couriousous <couriousous@mandriva.org> 1.5.0-1mdv2008.0
+ Revision: 54863
- 1.5.0
- Import vigra



* Sun Apr  2 2006 Couriousous <couriousous@mandriva.org> 1.4.0-1mdk
- 1.4.0

* Sat Oct  1 2005 Couriousous <couriousous@mandriva.org> 1.3.3-1mdk
- 1.3.3
- fix some warning

* Fri Jun 17 2005 Couriousous <couriousous@mandriva.org> 1.3.2-2mdk
- Rebuild

* Sun Apr 03 2005 Couriousous <couriousous@mandrake.org> 1.3.2-1mdk
- New Release
- Multiarch

* Sun Jan 23 2005 Couriousous <couriousous@mandrake.org> 1.3.1-1mdk
- New Release

* Thu Dec 08 2004 Couriouous <couriousous@mandrake.org> 1.3.0-1mdk
- 1.3.0
- Remove patch0, merged upstream

* Thu Jul 01 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-4mdk 
- more complete patch from upstream

* Wed Jun 09 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-3mdk 
- fixed build
- rpmbuildupdate aware
- dropped patch0

* Sat Mar 13 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-2mdk
- fix link

* Mon Jan 12 2004 Guillaume Rousse <guillomovitch@mandrake.org> 1.2.0-1mdk
- first mdk package (leafred <fred@lea-linux.org>)
